@@ -87,7 +87,7 @@ OFFG = PublisherStyle(
 
 
 def get_publisher_label(match: Match) -> str | None:
-    """Given a regex match object from `published_report.REPORT_PATTERN`,
+    """Given a regex match object from [Report Pattern][report-pattern],
     determine if it contains a group name representing a Report publisher.
 
     Examples:
